<template>
  <div class="system-add-user-container">
    <el-dialog :title="title" v-model="isShowDialog" width="50%">
      <el-form :model="form" size="default" ref="formRef" :rules="rules" label-width="120px">
        <el-row :gutter="35">
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="承包商名称" prop="contractorName">
              <el-input v-model.trim="form.contractorName" placeholder="承包商名称" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="承包商统一信用码" prop="contractorNumber">
              <el-input v-model.trim="form.contractorNumber" placeholder="承包商统一信用码" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="承包商法人" prop="contractorPerson">
              <el-input v-model.trim="form.contractorPerson" placeholder="承包商法人" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="合作状态" prop="contractorState">
              <el-select v-model="form.contractorState" placeholder="请选择合作状态">
                <el-option :key="1" label="合作中" :value="1"/>
                <el-option :key="2" label="曾合作" :value="2"/>
                <el-option :key="3" label="不合作" :value="3"/>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="承包商类型" prop="contractorType">
              <el-input v-model.trim="form.contractorType" placeholder="承包商类型" clearable></el-input>
            </el-form-item>
          </el-col>
<!--          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">-->
<!--            <el-form-item label="创建人姓名" prop="createBy">-->
<!--              <el-input v-model.trim="form.createBy" placeholder="创建人姓名" clearable></el-input>-->
<!--            </el-form-item>-->
<!--          </el-col>-->
<!--          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">-->
<!--            <el-form-item label="修改人姓名" prop="updateBy">-->
<!--              <el-input v-model.trim="form.updateBy" placeholder="修改人姓名" clearable></el-input>-->
<!--            </el-form-item>-->
<!--          </el-col>-->
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-if="title == '新增上报'? false : true">
            <el-form-item label="删除状态" prop="deleted">
              <el-radio-group v-model="form.deleted">
                <el-radio :label="0">未删除</el-radio>
                <el-radio :label="1">已删除</el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="isShowDialog = !isShowDialog" size="default">取 消</el-button>
            <el-button type="primary" v-throttle @click="onSubmit" size="default">确 定</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script lang="ts">
import { reactive, toRefs, onMounted, defineComponent, ref } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import axios from "axios";
import {contractorApi} from "/@/api/dataUpload/contractorManage";

// 定义接口来定义对象的类型
interface DataState {
  title: string
  isShowDialog: boolean
  form: {
    uuid: string
    companyCode: string
    contractorName: string
    contractorNumber: string
    contractorPerson: string
    contractorState: null | number
    contractorType: string
    deleted: null | number
    // createBy: string
    // updateBy: string
  }
  rules:{}
}

export default defineComponent({
  name: 'reportDialog',
  setup(props, context) {
    const formRef = ref()
    const state = reactive<DataState>({
      title: '',
      isShowDialog: false,
      form: {
        uuid: '',
        companyCode: '652310082',
        contractorName: '',
        contractorNumber: '',
        contractorPerson: '',
        contractorState: null,
        contractorType: '',
        deleted: 0
      },
      rules:{
        contractorName: [{ required: true, message: '请填写承包商名称', trigger: 'blur' }],
        contractorNumber: [{ required: true, message: '请填写承包商统一信用码', trigger: 'blur' }],
        contractorPerson: [{ required: true, message: '请填写承包商法人', trigger: 'blur' }],
        contractorState: [{ required: true, message: '请选择合作状态', trigger: 'blur' }],
        contractorType: [{ required: true, message: '请填写承包商类型', trigger: 'blur' }]
      }
    })

    // 页面加载时
    onMounted(() => {

    })
    // 打开弹窗
    const open = (type: string, data: object) => {
      state.isShowDialog = true;
      if (type === 'add') {
        state.title = '新增上报';
        state.form = {
          uuid: '',
          companyCode: '652310082',
          contractorName: '',
          contractorNumber: '',
          contractorPerson: '',
          contractorState: null,
          contractorType: '',
          deleted: 0
        }
      }else{
        state.title = '重新上报';
        Object.keys(state.form).forEach(key => {
          if (Object.prototype.hasOwnProperty.call(data,key)) {
            state.form[key] = JSON.parse(JSON.stringify(data))[key];
          }
        })
        state.form.deleted = data.delFlag
        // state.form = {
        //   uuid: data.uuid,
        //   companyCode: '652310082',
        //   contractorName: '',
        //   contractorNumber: '',
        //   contractorPerson: '',
        //   contractorState: null,
        //   contractorType: '',
        //   deleted: '0'
        // }
      }
    };

    // 新增修改
    const onSubmit = async () => {
      formRef.value.validate(async (valid:Boolean) => {
        if(valid){
          const res = await contractorApi().addContractor([state.form])
          if(res.data.code == 200){
            ElMessage({
              type:'success',
              message:'数据上报成功'
            })
            state.isShowDialog = false
          }else{
            ElMessage({
              type:'warning',
              message:res.data.msg
            })
          }
          context.emit('refresh');
        }else{
          ElMessage({
            type:'warning',
            message:'请完善基本信息'
          })
        }
      })
    }

    return {
      formRef,
      open,
      onSubmit,
      ...toRefs(state)
    };
  }
});
</script>
